Error page

# {{ status_code }} Error Page

This is an error page. It acts as a template and is passed 3 keyword arguments:

1. `status_code`: currently, this is `{{ status_code }}`
2. `kwargs`: if this error was caused by an uncaught exception or raising a HTTPError, `kwargs['exc_info']` is available as an exception triple.
3. `handler`: the handler object. For example, `handler.request.uri` is `{{ handler.request.uri }}`.

You may show any information you want here.